summary.impTest: Print summary of the benchmark for the imputation method.

View source: R/summary.impTest.R

summary.impTestR Documentation

Print summary of the benchmark for the imputation method.

Description

Print summary of the benchmark for the imputation method.

Usage

## S3 method for class 'impTest'
summary(object, ...)

Arguments

object

Object of S3 class impTest.

...

Additional parameters passed to other functions.


FuzzyImputationTest documentation built on June 22, 2026, 9:09 a.m.