summary.metComp: Print summary of the comparison of the imputation methods.

View source: R/summary.metComp.R

summary.metCompR Documentation

Print summary of the comparison of the imputation methods.

Description

Print summary of the comparison of the imputation methods.

Usage

## S3 method for class 'metComp'
summary(object, ...)

Arguments

object

Object of S3 class metComp.

...

Additional parameters passed to other functions.


FuzzyImputationTest documentation built on June 22, 2026, 9:09 a.m.